==> chaosmesh-model-5.3.0-sources.jar: annotations/io/fabric8/chaosmesh/v1alpha1/JVMReturnSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface JVMReturnSpecFluent<A extends JVMReturnSpecFluent<A>> extends Fluent<A> {


    public Boolean getAfter();
    public A withAfter(Boolean after);
    public Boolean hasAfter();
    public A withNewAfter(String arg1);
    public A withNewAfter(boolean arg1);
    public String getClassname();
    public A withClassname(String classname);
    public Boolean hasClassname();
    public A withNewClassname(StringBuilder arg1);
    public A withNewClassname(int[] arg1,int arg2,int arg3);
    public A withNewClassname(char[] arg1);
    public A withNewClassname(StringBuffer arg1);
    public A withNewClassname(byte[] arg1,int arg2);
    public A withNewClassname(byte[] arg1);
    public A withNewClassname(char[] arg1,int arg2,int arg3);
    public A withNewClassname(byte[] arg1,int arg2,int arg3);
    public A withNewClassname(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewClassname(String arg1);
    public String getMethodname();
    public A withMethodname(String methodname);
    public Boolean hasMethodname();
    public A withNewMethodname(StringBuilder arg1);
    public A withNewMethodname(int[] arg1,int arg2,int arg3);
    public A withNewMethodname(char[] arg1);
    public A withNewMethodname(StringBuffer arg1);
    public A withNewMethodname(byte[] arg1,int arg2);
    public A withNewMethodname(byte[] arg1);
    public A withNewMethodname(char[] arg1,int arg2,int arg3);
    public A withNewMethodname(byte[] arg1,int arg2,int arg3);
    public A withNewMethodname(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewMethodname(String arg1);
    public String getValue();
    public A withValue(String value);
    public Boolean hasValue();
    public A withNewValue(StringBuilder arg1);
    public A withNewValue(int[] arg1,int arg2,int arg3);
    public A withNewValue(char[] arg1);
    public A withNewValue(StringBuffer arg1);
    public A withNewValue(byte[] arg1,int arg2);
    public A withNewValue(byte[] arg1);
    public A withNewValue(char[] arg1,int arg2,int arg3);
    public A withNewValue(byte[] arg1,int arg2,int arg3);
    public A withNewValue(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewValue(String arg1);
}

==> chaosmesh-model-5.3.2-sources.jar: annotations/io/fabric8/chaosmesh/v1alpha1/JVMReturnSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface JVMReturnSpecFluent<A extends JVMReturnSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public Boolean getAfter();
    public A withAfter(Boolean after);
    public Boolean hasAfter();
    public A withNewAfter(String arg1);
    public A withNewAfter(boolean arg1);
    public String getClassname();
    public A withClassname(String classname);
    public Boolean hasClassname();
    public A withNewClassname(StringBuilder arg1);
    public A withNewClassname(int[] arg1,int arg2,int arg3);
    public A withNewClassname(char[] arg1);
    public A withNewClassname(StringBuffer arg1);
    public A withNewClassname(byte[] arg1,int arg2);
    public A withNewClassname(byte[] arg1);
    public A withNewClassname(char[] arg1,int arg2,int arg3);
    public A withNewClassname(byte[] arg1,int arg2,int arg3);
    public A withNewClassname(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewClassname(String arg1);
    public String getMethodname();
    public A withMethodname(String methodname);
    public Boolean hasMethodname();
    public A withNewMethodname(StringBuilder arg1);
    public A withNewMethodname(int[] arg1,int arg2,int arg3);
    public A withNewMethodname(char[] arg1);
    public A withNewMethodname(StringBuffer arg1);
    public A withNewMethodname(byte[] arg1,int arg2);
    public A withNewMethodname(byte[] arg1);
    public A withNewMethodname(char[] arg1,int arg2,int arg3);
    public A withNewMethodname(byte[] arg1,int arg2,int arg3);
    public A withNewMethodname(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewMethodname(String arg1);
    public String getValue();
    public A withValue(String value);
    public Boolean hasValue();
    public A withNewValue(StringBuilder arg1);
    public A withNewValue(int[] arg1,int arg2,int arg3);
    public A withNewValue(char[] arg1);
    public A withNewValue(StringBuffer arg1);
    public A withNewValue(byte[] arg1,int arg2);
    public A withNewValue(byte[] arg1);
    public A withNewValue(char[] arg1,int arg2,int arg3);
    public A withNewValue(byte[] arg1,int arg2,int arg3);
    public A withNewValue(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewValue(String arg1);
}
